@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Abstract Library for Parallel Search (ALPS).     *
  *                                                                           *
- * ALPS is distributed under the Common Public License as part of the        *
+ * ALPS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors: Yan Xu, Lehigh University                                       *
@@ -10,7 +10,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #include "AlpsConfig.h"
@@ -29,7 +29,6 @@
 #include "KnapSolution.h"
 #include "KnapTreeNode.h"
 
-//#############################################################################
 //#############################################################################
 
 int main(int argc, char* argv[])
@@ -59,7 +58,7 @@ int main(int argc, char* argv[])
 	broker.rootSearch(root);
     
 	// 5: Report the best solution found and its ojective value
-	//broker.printBestSolution();
+	broker.printBestSolution();
         
 #ifdef NF_DEBUG
 	const int numSol = broker.getNumKnowledges(AlpsKnowledgeTypeSolution);
@@ -79,3 +78,6 @@ int main(int argc, char* argv[])
 
     return 0;
 }
+
+//#############################################################################
+
