@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Abstract Library for Parallel Search (ALPS).     *
  *                                                                           *
- * ALPS is distributed under the Common Public License as part of the        *
+ * ALPS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors: Yan Xu, Lehigh University                                       *
@@ -10,7 +10,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #include <iostream>
@@ -130,6 +130,10 @@ KnapTreeNode::process(bool isRoot, bool rampUp)
 		message(ALPS_S_SEARCH_SOL, getKnowledgeBroker()->messages())
 		    << (getKnowledgeBroker()->getProcRank()) 
 		    << valRelax << CoinMessageEol;
+
+	    if (depth_ < getKnowledgeBroker()->getBestSolDepth()){
+		getKnowledgeBroker()->setBestSolDepth(depth_);
+	    }
 	}    
 	setStatus(AlpsNodeStatusFathomed);   // set the status to fathomed
     }
