@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Abstract Library for Parallel Search (ALPS).     *
  *                                                                           *
- * ALPS is distributed under the Common Public License as part of the        *
+ * ALPS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2006, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #ifndef AlpsKnowledgeBroker_h_
@@ -53,7 +53,7 @@ class AlpsKnowledgeBroker {
     AlpsKnowledgeBroker& operator=(const AlpsKnowledgeBroker&);
 
     /** Stores registered knowledge. */
-    std::map<std::string, AlpsKnowledge*> decodeMap_;
+    std::map<int, AlpsKnowledge*> decodeMap_;
     
  protected:
 
@@ -112,8 +112,24 @@ class AlpsKnowledgeBroker {
     /** Secondary timer. */
     AlpsTimer tempTimer_;
 
-    /** The number of nodes have been processed. */
+    /** The number of solutions found. */
+    int solNum_;
+
+    /** The number of nodes that have been processed. */
     int nodeProcessedNum_;
+
+    /** The number of nodes that have been branched. */
+    int nodeBranchedNum_;
+
+    /** The number of nodes that have been discarded before processing. */
+    int nodeDiscardedNum_;
+
+    /** The number of nodes that are pregnant. */
+    int nodePartialNum_;
+
+    /** To record how many nodes processed by the system
+        (used in parallel code). */
+    int systemNodeProcessed_;
     
     /** The number of nodes left. */
     int nodeLeftNum_;
@@ -121,8 +137,14 @@ class AlpsKnowledgeBroker {
     /** The depth of the tree. */
     int treeDepth_;
 
+    /** The number of nodes pocessed to find the solution. */
+    int bestSolNode_;
+
+    /** Peak memory usage. */
+    double peakMemory_;
+
     /** The status of search when terminated. */
-    AlpsSolStatus solStatus_;
+    AlpsExitStatus exitStatus_;
     //@}
     
     /** @name Search strategy
@@ -178,6 +200,12 @@ class AlpsKnowledgeBroker {
     /** The size of largest message buffer can be sent or received. */
     int largeSize_;
 
+    /** Has user input balance period */
+    bool userBalancePeriod_;
+    
+    /** Times that node log is printed. */
+    int numNodeLog_;
+    
  public:
 
     /** Default constructor. */
@@ -199,12 +227,10 @@ class AlpsKnowledgeBroker {
         NOTE: take over user knowledge's memory ownership, user doesn't
         need free memory. 
     */
-    void registerClass(const char * name, AlpsKnowledge* userKnowledge) {
-        std::string newName = name;
-        
+    void registerClass(int name, AlpsKnowledge* userKnowledge) {
         // Check if alread have one.
-        std::map<std::string, AlpsKnowledge*>::iterator pos, pos1;
-        pos = decodeMap_.find(newName);
+        std::map<int, AlpsKnowledge*>::iterator pos, pos1;
+        pos = decodeMap_.find(name);
         pos1 = decodeMap_.end();
         
         if (pos != pos1) {
@@ -213,7 +239,7 @@ class AlpsKnowledgeBroker {
             delete kl;
         }
         
-        decodeMap_[newName] = userKnowledge;
+        decodeMap_[name] = userKnowledge;
     }
 
     /** This method returns the pointer to an empty object of the registered
@@ -223,12 +249,8 @@ class AlpsKnowledgeBroker {
 	whose type is <code>name</code>:<br>
 	<code>obj = AlpsKnowledge::decoderObject(name)->decode(buf) </code> 
     */
-    const AlpsKnowledge* decoderObject(const char* name) {
-        std::string newName = name;
-	return decodeMap_[newName];
-    }
 
-    const AlpsKnowledge* decoderObject(std::string name) {
+    const AlpsKnowledge* decoderObject(int name) {
 	return decodeMap_[name];
     }
     //@}
@@ -269,6 +291,15 @@ class AlpsKnowledgeBroker {
     void setModel(AlpsModel *m) { model_ = m; }
     //@}
 
+    /** Get tree depth */
+    int getTreeDepth() { return treeDepth_; }
+
+    /** Set peak memory usage. */
+    void setPeakMemory(double size) { peakMemory_ = size; }
+
+    /** Get peak memory usage. */
+    double getPeakMemory() { return peakMemory_; }
+    
     /** @name Interface with the knowledge pools 
      *  
      */
@@ -278,7 +309,7 @@ class AlpsKnowledgeBroker {
     
     /** Add a knowledge pool into the Knowledge pools */
     inline void addKnowledgePool(AlpsKnowledgeType kt, AlpsKnowledgePool* kp) {
-	if(kt == ALPS_SOLUTION || kt == ALPS_SUBTREE) {
+	if(kt == AlpsKnowledgeTypeSolution || kt == AlpsKnowledgeTypeSubTree) {
 	    // AlpsKnowledgePool* akp = static_cast<AlpsKnowledgePool*>(kp);
 	    pools_->insert
 		(std::pair<AlpsKnowledgeType, AlpsKnowledgePool*>(kt, kp));
@@ -291,7 +322,7 @@ class AlpsKnowledgeBroker {
   
     /** Retrieve a knowledge pool in the Knowledge base */
     inline  AlpsKnowledgePool* getKnowledgePool(AlpsKnowledgeType kt) const { 
-	if(kt == ALPS_SOLUTION || kt == ALPS_SUBTREE) {
+	if(kt == AlpsKnowledgeTypeSolution || kt == AlpsKnowledgeTypeSubTree) {
 	    return (*pools_)[kt];
         }
 	else {
@@ -306,7 +337,7 @@ class AlpsKnowledgeBroker {
     /** Query the max number of knowledge can be stored in a given 
 	type of knowledge pools. */
     virtual int getMaxNumKnowledges(AlpsKnowledgeType kt) const {
-	if(kt == ALPS_SOLUTION || kt == ALPS_SUBTREE) {
+	if(kt == AlpsKnowledgeTypeSolution || kt == AlpsKnowledgeTypeSubTree) {
 	    return getKnowledgePool(kt)->getMaxNumKnowledges();
         }
 	else {
@@ -318,7 +349,7 @@ class AlpsKnowledgeBroker {
     /** Set the max number of knowledge can be stored in a given 
 	type o fknowledge pools. */
     virtual void setMaxNumKnowledges(AlpsKnowledgeType kt, int num) {
-	if(kt == ALPS_SOLUTION || kt == ALPS_SUBTREE) {
+	if(kt == AlpsKnowledgeTypeSolution || kt == AlpsKnowledgeTypeSubTree) {
 	    getKnowledgePool(kt)->setMaxNumKnowledges(num);
         }
 	else {
@@ -330,7 +361,7 @@ class AlpsKnowledgeBroker {
     /** Query whether there are knowledges in the given type of 
 	knowledge pools. */
     virtual bool hasKnowledge(AlpsKnowledgeType kt) const {
-	if(kt == ALPS_SOLUTION || kt == ALPS_SUBTREE)
+	if(kt == AlpsKnowledgeTypeSolution || kt == AlpsKnowledgeTypeSubTree)
 	    return getKnowledgePool(kt)->hasKnowledge();
 	else
 	    throw CoinError("Broker doesn't manage this type of knowledge", 
@@ -340,7 +371,7 @@ class AlpsKnowledgeBroker {
     /** Get a knowledge, but doesn't remove it from the pool*/
     virtual std::pair<AlpsKnowledge*, double> 
 	getKnowledge(AlpsKnowledgeType kt) const {
-	if(kt == ALPS_SOLUTION || kt == ALPS_SUBTREE) {
+	if(kt == AlpsKnowledgeTypeSolution || kt == AlpsKnowledgeTypeSubTree) {
 	    return getKnowledgePool(kt)->getKnowledge();
         }
 	else {
@@ -351,7 +382,7 @@ class AlpsKnowledgeBroker {
 
     /** Remove the a knowledge from the given type of knowledge pools.*/
     virtual void popKnowledge(AlpsKnowledgeType kt) {
-	if(kt == ALPS_SOLUTION || kt == ALPS_SUBTREE) {
+	if(kt == AlpsKnowledgeTypeSolution || kt == AlpsKnowledgeTypeSubTree) {
 	    getKnowledgePool(kt)->popKnowledge();
         }
 	else {
@@ -368,7 +399,7 @@ class AlpsKnowledgeBroker {
     virtual void getAllKnowledges (AlpsKnowledgeType kt, 
 				   std::vector<std::pair<AlpsKnowledge*, 
 				   double> >& kls)  const { 
-	if(kt == ALPS_SOLUTION || kt == ALPS_SUBTREE) {
+	if(kt == AlpsKnowledgeTypeSolution || kt == AlpsKnowledgeTypeSubTree) {
 	    getKnowledgePool(kt)->getAllKnowledges(kls);
         }
 	else {
@@ -381,7 +412,7 @@ class AlpsKnowledgeBroker {
     virtual void addKnowledge(AlpsKnowledgeType kt, 
 			      AlpsKnowledge* kl, 
 			      double value ) { 
-	if(kt == ALPS_SOLUTION || kt == ALPS_SUBTREE) {
+	if(kt == AlpsKnowledgeTypeSolution || kt == AlpsKnowledgeTypeSubTree) {
 	    getKnowledgePool(kt)->addKnowledge(kl, value);
         }
 	else {
@@ -399,6 +430,26 @@ class AlpsKnowledgeBroker {
 	return nodeProcessedNum_;
     }
 
+    /** Query the number of node processed by this process. */
+    int getNumNodesBranched() const {
+	return nodeBranchedNum_;
+    }
+
+    /** Query the number of node processed by this process. */
+    int getNumNodesDiscarded() const {
+	return nodeDiscardedNum_;
+    }
+
+    /** Query the number of node in the queue that are pregnant. */
+    int getNumNodesPartial() const {
+	return nodePartialNum_;
+    }
+
+    /** Query the number of node processed by the system. */
+    int getNumNodesProcessedSystem() const {
+	return systemNodeProcessed_;
+    }
+
     /** Update the number of left nodes on this process. */
     virtual int updateNumNodesLeft();
     
@@ -406,13 +457,13 @@ class AlpsKnowledgeBroker {
     virtual AlpsTreeNode* getBestNode() const;
 
     /** Query search termination status. */
-    AlpsSolStatus getSolStatus() const {
-	return solStatus_;
+    AlpsExitStatus getSolStatus() const {
+	return exitStatus_;
     }
 
     /** Set terminate status. */
-    void setSolStatus(AlpsSolStatus status) {
-	solStatus_ = status;
+    void setExitStatus(AlpsExitStatus status) {
+	exitStatus_ = status;
     }
 
     /** Query timer. */
@@ -464,6 +515,11 @@ class AlpsKnowledgeBroker {
         of the best solution that it knows. */
     virtual double getBestQuality() const = 0;
 
+    /** Get best estimalted quality in system. */
+    virtual double getBestEstimateQuality() { return ALPS_OBJ_MAX; }
+
+    virtual int getNumNodeLeftSystem(){ return nodeLeftNum_; }
+
     /** The process (serial) / the master (parallel) outputs the best 
 	solution that it knows to a file or std::out. */
     virtual void printBestSolution(char* outputFile = 0) const = 0;
@@ -477,8 +533,7 @@ class AlpsKnowledgeBroker {
 
     /** Query the type (master, hub, or worker) of the process */
     virtual AlpsProcessType getProcType() const
-    { return AlpsProcessTypeMaster; } /* Serial is master */
-    
+    { return AlpsProcessTypeSerial; } /* Default is serial */
     
     /** @name Query and set node index
      *  
@@ -559,6 +614,12 @@ class AlpsKnowledgeBroker {
 
     /** Return log file level. */
     int getlogFileLevel() { return logFileLevel_; }
+
+    /** Get times that node log has been printed */
+    int getNumNodeLog() const { return numNodeLog_; }
+    
+    /** Get times that node log has been printed */
+    void setNumNodeLog(int num) { numNodeLog_ = num; }
     //@}
 };
 #endif
