@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Abstract Library for Parallel Search (ALPS).     *
  *                                                                           *
- * ALPS is distributed under the Common Public License as part of the        *
+ * ALPS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #ifndef AlpsSolutionPool_h_
@@ -63,7 +63,9 @@ class AlpsSolutionPool : public AlpsKnowledgePool {
 
     /** query the current number of solutions */
     //   int getNumSolutions() const { return solutions_.size(); }
-    inline int getNumKnowledges() const { return static_cast<int> (solutions_.size()); }
+    inline int getNumKnowledges() const { 
+	return static_cast<int> (solutions_.size()); 
+    }
 
     /** return true if there are any solution stored in the solution pool */
     inline bool hasKnowledge() const 
