@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Abstract Library for Parallel Search (ALPS).     *
  *                                                                           *
- * ALPS is distributed under the Common Public License as part of the        *
+ * ALPS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #ifndef AlpsTreeNode_h_
@@ -189,6 +189,8 @@ class AlpsTreeNode : public AlpsKnowledge {
 	return status_ == AlpsNodeStatusBranched; }
     inline bool isFathomed() const  {
 	return status_ == AlpsNodeStatusFathomed; }
+    inline bool isDiscarded() const  {
+	return status_ == AlpsNodeStatusDiscarded; }
     ///@}
     
     /** Query/set node in-process indicator. */
@@ -339,6 +341,7 @@ class AlpsTreeNode : public AlpsKnowledge {
      *  \param isRoot  Indicate if this node is a root of a subtree.
      *  \param rampUp  Indicate if it is in ramp up period. Only useful
      *                 for parallel code. 
+     * Currently, the return code of this method is not used. 
      */
     virtual int process(bool isRoot = false, bool rampUp = false) = 0;
     
