@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Bcps Linear Solver (BLIS).                       *
  *                                                                           *
- * BLIS is distributed under the Common Public License as part of the        *
+ * BLIS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -17,9 +17,8 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2005, International Business Machines                  *
- * Corporation, Lehigh University, Yan Xu, Ted Ralphs, Matthew Salzman and   *
- * others. All Rights Reserved.                                              *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * All Rights Reserved.                                                      *
  *===========================================================================*/
 
 #include "CoinHelperFunctions.hpp"
@@ -387,7 +386,7 @@ BlisBranchStrategyStrong::createCandBranchObjects(int numPassesLeft)
 					       solver->getColSolution(), 
 					       newObjValue);
 			model->getKnowledgeBroker()->
-                            addKnowledge(ALPS_SOLUTION, 
+                            addKnowledge(AlpsKnowledgeTypeSolution, 
                                          ksol, 
                                          newObjValue);
 
@@ -481,7 +480,7 @@ BlisBranchStrategyStrong::createCandBranchObjects(int numPassesLeft)
 					     newObjValue);
                         
 			model->getKnowledgeBroker()->
-                            addKnowledge(ALPS_SOLUTION, 
+                            addKnowledge(AlpsKnowledgeTypeSolution, 
                                          ksol, 
                                          newObjValue);
                         
