@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Branch, Constrain and Price Software (BiCePS)    *
  *                                                                           *
- * BiCePS is distributed under the Common Public License as part of the      *
+ * BiCePS is distributed under the Eclipse Public License as part of the     *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -16,7 +16,7 @@
  *          Laszlo Ladanyi, IBM T.J. Watson Research Center                  *
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           *
- * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
  * All Rights Reserved.                                                      *
  *===========================================================================*/
 
@@ -36,14 +36,14 @@
 
 /* Compare N branch objects and identify bestObject_. Return index 
    of best and sets way of branch bestObject_. */
-int
+BcpsBranchObject *
 BcpsBranchStrategy::bestBranchObject()
 {
     int i, betterDir;
     int bestDir = 0;
     int bestBrObjIndex = -1;
     
-    if (numBranchObjects_) {
+    if (numBranchObjects_ > 1) {
 
         //--------------------------------------------------	
         // Clear best members.
@@ -72,10 +72,7 @@ BcpsBranchStrategy::bestBranchObject()
             branchObjects_[bestBrObjIndex] = NULL;
         }
 	else {
-#ifdef BLIS_DEBUG
-	  std::cout<<"ERROR: Could not find a branching object."<< std::endl;
-#endif
-            assert(0);
+	    bestBranchObject_ = NULL;
         }
         
         //--------------------------------------------------
@@ -88,17 +85,16 @@ BcpsBranchStrategy::bestBranchObject()
                 branchObjects_[i] = NULL;
             }
         }
-        delete [] branchObjects_;
-        branchObjects_ = NULL;
-        numBranchObjects_ = 0;
     }
-    else {
-        if (bestBranchObject_) {
-            return bestBranchObject_->getObjectIndex();
-        }
+    else{
+	bestBranchObject_ = branchObjects_[0];
     }
-    
-    return bestBrObjIndex;
+
+    delete [] branchObjects_;
+    branchObjects_ = NULL;
+    numBranchObjects_ = 0;
+
+    return bestBranchObject_;
 }
   
 //#############################################################################
