@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Branch, Constrain and Price Software (BiCePS)    *
  *                                                                           *
- * BiCePS is distributed under the Common Public License as part of the      *
+ * BiCePS is distributed under the Eclipse Public License as part of the     *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -16,7 +16,7 @@
  *          Laszlo Ladanyi, IBM T.J. Watson Research Center                  *
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           *
- * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
  * All Rights Reserved.                                                      *
  *===========================================================================*/
 
@@ -113,6 +113,12 @@ class BcpsModel : public AlpsModel {
     void setNumCoreVariables(int num) { numCoreVariables_ = num; }
     /**@}*/
 
+    /** Return list of variables. */
+    std::vector<BcpsVariable *> getVariables() const { return variables_; }
+
+    /** Return list of constraints. */
+    std::vector<BcpsConstraint *> getConstrints() const { return constraints_; }
+
     /** Get the message handler. */
     CoinMessageHandler * bcpsMessageHandler() const 
     { return bcpsMessageHandler_; }
